from flask import Flask, render_template, request, redirect
from flask_sqlalchemy import SQLAlchemy

app = Flask(__name__)
app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///employees.db'
db = SQLAlchemy(app)

class Employee(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    name = db.Column(db.String(100), nullable=False)
    position = db.Column(db.String(100), nullable=False)
    contact_info = db.Column(db.String(100), nullable=False)

@app.route('/')
def index():
    employees = Employee.query.all()
    return render_template('index.html', employees=employees)

@app.route('/add', methods=['POST', 'GET'])
def add_employee():
    if request.method == "POST":
        name = request.form['name']
        position = request.form['position']
        contact_info = request.form['contact_info']
        
        employee = Employee(name=name, position=position, contact_info=contact_info)

        try:
            db.session.add(employee)
            db.session.commit()
            return redirect('/')
        except:
            return "Произошла ошибка при добавлении информации о сотруднике"
    else:
        return render_template('add.html')

@app.route('/update/<int:id>', methods=['POST', 'GET'])
def update_employee(id):
    employee = Employee.query.get(id)
    if request.method == "POST":
        employee.name = request.form['name']
        employee.position = request.form['position']
        employee.contact_info = request.form['contact_info']

        try:
            db.session.commit()
            return redirect('/')
        except:
            return "Произошла ошибка при обновлении информации о сотруднике"
    else:
        return render_template('update.html', employee=employee)

@app.route('/delete/<int:id>')
def delete_employee(id):
    employee = Employee.query.get(id)

    try:
        db.session.delete(employee)
        db.session.commit()
        return redirect('/')
    except:
        return "Произошла ошибка при удалении информации о сотруднике"

if __name__ == "__main__":
    app.run(debug=True)
